@@ -1,15 +1,17 @@
+from dataconf.main import cli
 from dataconf.main import dict
 from dataconf.main import dump
 from dataconf.main import dumps
 from dataconf.main import env
-from dataconf.main import env_dict_list
 from dataconf.main import file
+from dataconf.main import HOCON
 from dataconf.main import load
 from dataconf.main import loads
 from dataconf.main import multi
 from dataconf.main import parse
 from dataconf.main import string
 from dataconf.main import url
+from dataconf.main import YAML
 from dataconf.version import __version__
 
 __all__ = [
@@ -22,8 +24,10 @@ __all__ = [
     "dict",
     "file",
     "string",
+    "cli",
     "multi",
     "parse",
-    "env_dict_list",
+    "YAML",
+    "HOCON",
     "__version__",
 ]
